@@ -121,7 +121,7 @@ void QRKMessageHandler(QtMsgType type, const QMessageLogContext &, const QString
     if (!confname.isEmpty()) confname = "_" + confname;
     QFile outFile(
         QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QString("/qrk%1.log").arg(confname));
-    if (outFile.size() > 20000000) /*20 Mega*/
+    if (outFile.size() > 10000000) /*10 Mega*/
         Backup::pakLogFile();
 
     if (!txt.isEmpty()) {
@@ -481,14 +481,24 @@ int main(int argc, char *argv[])
     }
 
     // DateTime check
-    if (Database::getLastJournalEntryDate().secsTo(QDateTime::currentDateTime()) < 0) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+    qlonglong lastJournalTime = Database::getLastJournalEntryDateTime().toSecsSinceEpoch();
+    qlonglong currentTime = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+#else
+    qlonglong lastJournalTime = static_cast<qlonglong>(Database::getLastJournalEntryDateTime().toTime_t());
+    qlonglong currentTime = static_cast<qlonglong>(QDateTime::currentDateTimeUtc().toTime_t());
+#endif
+    if (currentTime < lastJournalTime) {
         splash->setHidden(true);
+
         QMessageBox messageBox(QMessageBox::Critical, QObject::tr("Eventueller Datum/Uhrzeit Fehler"),
-            QObject::tr("ACHTUNG! Die Uhrzeit des Computers ist eventuell "
-                        "falsch.\n\nLetzter Datenbankeintrag: %1\nDatum/Uhrzeit: %2")
-                .arg(Database::getLastJournalEntryDate().toString())
+            QObject::tr(
+                "ACHTUNG! Die Uhrzeit des Computers ist eventuell "
+                "falsch (Rückstellung der Systemzeit erkannt).\n\nLetzter Datenbankeintrag: %1\nDatum/Uhrzeit: %2")
+                .arg(Database::getLastJournalEntryDateTime().toString())
                 .arg(QDateTime::currentDateTime().toString()),
             QMessageBox::Yes | QMessageBox::No, Q_NULLPTR);
+
         messageBox.setButtonText(QMessageBox::Yes, QObject::tr("QRK beenden?"));
         messageBox.setButtonText(QMessageBox::No, QObject::tr("Weiter machen"));
 
@@ -517,8 +527,9 @@ int main(int argc, char *argv[])
 
     // DEP-7 Check
     QStringList error;
+    QString cardType = "none";
     if (!Database::isCashRegisterInAktive() && !DemoMode::isDemoMode() && RKSignatureModule::isDEPactive()
-        && !Utils::checkTurnOverCounter(error)) {
+        && !Utils::checkTurnOverCounter(error, cardType)) {
         splash->setHidden(true);
         QMessageBox messageBox(QMessageBox::Critical, QObject::tr("DEP-7 Fehler"),
             QObject::tr("ACHTUNG! Das gespeicherte DEP-7 hat einen oder mehrere "
@@ -635,12 +646,13 @@ int main(int argc, char *argv[])
     if (QApplication::applicationVersion().contains("BETA"))
         FvUpdater::sharedUpdater()->SetFeedURL("http://service.ckvsoft.at/qrk/updates/BETA/Appcast.xml");
     else
-        FvUpdater::sharedUpdater()->SetFeedURL("http://service.ckvsoft.at/qrk/updates/v1.28/Appcast.xml");
+        FvUpdater::sharedUpdater()->SetFeedURL("http://service.ckvsoft.at/qrk/updates/v1.32/Appcast.xml");
     FvUpdater::sharedUpdater()->setRequiredSslFingerPrint("c3b038cb348c7d06328579fb950a48eb"); // Optional
     FvUpdater::sharedUpdater()->setHtAuthCredentials("username",
         "password"); // Optional
     FvUpdater::sharedUpdater()->setUserCredentials(QUrl::toPercentEncoding(Database::getShopName()) + "("
-        + fp.getSystemUniqueId() + ")/" + Database::getCashRegisterId() + "/" + QApplication::applicationVersion());
+        + fp.getSystemUniqueId() + ")/" + Database::getCashRegisterId() + "/" + QApplication::applicationVersion() + "/"
+        + cardType);
     FvUpdater::sharedUpdater()->setSkipVersionAllowed(false); // Optional
     FvUpdater::sharedUpdater()->setRemindLaterAllowed(true);  // Optional
     // Finish Up old Updates
